@@ -2,10 +2,10 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -26,7 +26,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -149,7 +149,7 @@ class StackROIBatch(object):
                 names[idxmin(j)] = "ROI " + roi + (" %s at Min." % roiType)
 
         # Allocate memory for result
-        roidtype = numpy.float
+        roidtype = numpy.float64
         results = outbuffer.allocateMemory('roisum',
                                            shape=roiShape,
                                            dtype=roidtype,
@@ -170,8 +170,8 @@ class StackROIBatch(object):
                     rawSum = 0.0
                     netSum = 0.0
                 else:
-                    roichunk = chunk[:, idx[j]]
-                    rawSum = roichunk.sum(axis=1, dtype=numpy.float)
+                    roichunk = numpy.array(chunk[:, idx[j]], copy=False, dtype=numpy.float64)
+                    rawSum = roichunk.sum(axis=1, dtype=numpy.float64)
                     deltaX = xw[j][iXMaxList[j]] - xw[j][iXMinList[j]]
                     left = roichunk[:, iXMinList[j]]
                     right = roichunk[:, iXMaxList[j]]
@@ -179,7 +179,7 @@ class StackROIBatch(object):
                     if abs(deltaX) > 0.0:
                         slope = deltaY / float(deltaX)
                         background = left * len(xw[j]) + slope * \
-                                    (xw[j] - xw[j][iXMinList[j]]).sum(dtype=numpy.float)
+                                    (xw[j] - xw[j][iXMinList[j]]).sum(dtype=numpy.float64)
                         netSum = rawSum - background
                     else:
                         netSum = 0.0
@@ -363,7 +363,7 @@ def main():
                      sys.argv[1:],
                      options,
                      longoptions)
-    except:
+    except Exception:
         _logger.error(sys.exc_info()[1])
         sys.exit(1)
     outputDir = None
