@@ -2,7 +2,7 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2004-2022 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF.
@@ -35,12 +35,12 @@ import numpy
 import traceback
 import copy
 from PyMca5.PyMcaGui import PyMcaQt as qt
-from PyMca5.PyMcaGui import PyMca_Icons
+from PyMca5.PyMcaGui.plotting import PyMca_Icons
 IconDict = PyMca_Icons.IconDict
 from PyMca5.PyMcaGraph.backends.MatplotlibBackend \
      import MatplotlibBackend as backend
-from PyMca5.PyMcaGui import PlotWindow
-from PyMca5.PyMcaPhysics import XASNormalization
+from PyMca5.PyMcaGui.plotting import PlotWindow
+from PyMca5.PyMcaPhysics.xas import XASNormalization
 
 POLYNOM_OPTIONS = ['Modif. Victoreen',
                    'Victoreen',
@@ -346,7 +346,7 @@ class XASNormalizationWindow(qt.QWidget):
                                             emin=self.energy.min(),
                                             emax=self.energy.max())
                 self.__lastDict['edge_energy'] = edgeEnergy
-            except:
+            except Exception:
                 pass
         parameters = {}
         parameters['pre_edge_order'] = ddict['pre_edge']['polynomial']
@@ -364,7 +364,7 @@ class XASNormalizationWindow(qt.QWidget):
                                                             post_edge_regions=postRegions,
                                                             algorithm=algorithm,
                                                             algorithm_parameters=parameters)
-        except:
+        except Exception:
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setWindowTitle("Normalization Error")
