@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF.
@@ -35,6 +35,11 @@ import subprocess
 import logging
 
 from PyMca5.PyMcaGui import PyMcaQt as qt
+if sys.platform.startswith("darwin"):
+    import threading
+    QThread = threading.Thread
+else:
+    QThread = qt.QThread
 
 QTVERSION = qt.qVersion()
 try:
@@ -601,14 +606,14 @@ class McaBatchGUI(qt.QWidget):
                 fileinfo = ffile.GetSourceInfo()
                 if fileinfo['KeyList'] == []:ffile=None
                 return "EdfFile"
-            except:
+            except Exception:
                 pass
             if (ffile is None):
                 ffile   = SpecFileLayer.SpecFileLayer()
                 ffile.SetSource(inputfile)
             del ffile
             return "Specfile"
-        except:
+        except Exception:
             qt.QMessageBox.critical(self,
                                     sys.exc_info()[0],
                                     'I do not know what to do with file\n %s' % ffile)
@@ -774,7 +779,8 @@ class McaBatchGUI(qt.QWidget):
             def cleanup():
                 b.pleasePause = 0
                 b.pleaseBreak = 1
-                b.wait()
+                if hasattr(b, "wait"):
+                    b.wait()
                 qApp = qt.QApplication.instance()
                 qApp.processEvents()
                 qApp = None
@@ -808,7 +814,8 @@ class McaBatchGUI(qt.QWidget):
             def cleanup():
                 b.pleasePause = 0
                 b.pleaseBreak = 1
-                b.wait()
+                if hasattr(b, "wait"):
+                    b.wait()
                 qApp = qt.QApplication.instance()
                 qApp.processEvents()
 
@@ -836,7 +843,7 @@ class McaBatchGUI(qt.QWidget):
                 if not os.path.exists(os.path.join(dirname, "LegacyPyMcaBatch.py")):
                     # script usage case
                     dirname = os.path.dirname(EdfFileSimpleViewer.__file__)
-            except:
+            except Exception:
                 # __file__ is not defined
                 dirname = os.path.dirname(EdfFileSimpleViewer.__file__)
                 frozen = True
@@ -968,7 +975,7 @@ class McaBatchGUI(qt.QWidget):
                 except UnicodeEncodeError:
                     try:
                         subprocess.call(cmd.encode(sys.getfilesystemencoding()))
-                    except:
+                    except Exception:
                         # be ready for any weird error like missing that encoding
                         try:
                             subprocess.call(cmd.encode('utf-8'))
@@ -984,7 +991,7 @@ class McaBatchGUI(qt.QWidget):
                 if not os.path.exists(os.path.join(dirname, "LegacyPyMcaBatch.py")):
                     # script usage case
                     dirname = os.path.dirname(EdfFileSimpleViewer.__file__)
-            except:
+            except Exception:
                 # __file__ is not defined
                 dirname = os.path.dirname(EdfFileSimpleViewer.__file__)
                 frozen = True
@@ -1098,7 +1105,7 @@ class McaBatchGUI(qt.QWidget):
         if os.path.exists(listfile):
             try:
                 os.remove(listfile)
-            except:
+            except Exception:
                 _logger.error("Cannot delete file %s", listfile)
                 raise
         if config is None:
@@ -1163,7 +1170,7 @@ class McaBatchGUI(qt.QWidget):
         else:
             work.buildOutput(delete=True)
 
-class McaBatch(McaAdvancedFitBatch.McaAdvancedFitBatch, qt.QThread):
+class McaBatch(McaAdvancedFitBatch.McaAdvancedFitBatch, QThread):
     def __init__(self, parent, configfile, filelist=None, outputdir = None,
                      roifit = None, roiwidth=None, overwrite=1,
                      filestep=1, mcastep=1, concentrations=0,
@@ -1183,7 +1190,7 @@ class McaBatch(McaAdvancedFitBatch.McaAdvancedFitBatch, qt.QThread):
                                                          chunk=chunk,
                                                          selection=selection,
                                                          lock=lock)
-        qt.QThread.__init__(self)
+        QThread.__init__(self)
         self.parent = parent
         self.pleasePause = 0
 
@@ -1381,7 +1388,7 @@ class McaBatchWindow(qt.QWidget):
                 if os.path.exists(self.htmlindex):
                     try:
                         os.remove(self.htmlindex)
-                    except:
+                    except Exception:
                         _logger.warning("cannot delete file %s", self.htmlindex)
         nfiles = len(indexlist)-filebeginoffset-fileendoffset
         self.status.setText("Processing file %s" % file)
@@ -1442,7 +1449,7 @@ class McaBatchWindow(qt.QWidget):
                     else:
                         self.__htmlReport(filename, key, outputdir,
                                           useExistingFiles, info, firstmca = False)
-            except:
+            except Exception:
                 _logger.warning("ERROR on REPORT %s", sys.exc_info())
                 _logger.warning("%s", sys.exc_info()[1])
                 _logger.warning("filename = %s key =%s ", (filename, key))
@@ -1471,14 +1478,14 @@ class McaBatchWindow(qt.QWidget):
         if not os.path.exists(fitdir):
             try:
                 os.mkdir(fitdir)
-            except:
+            except Exception:
                 _logger.warning("I could not create directory %s", fitdir)
                 return
         fitdir = os.path.join(fitdir, filename+"_HTMLDIR")
         if not os.path.exists(fitdir):
             try:
                 os.mkdir(fitdir)
-            except:
+            except Exception:
                 _logger.warning("I could not create directory %s", fitdir)
                 return
         localindex = os.path.join(fitdir, "index.html")
@@ -1492,7 +1499,7 @@ class McaBatchWindow(qt.QWidget):
             if not useExistingFiles:
                 try:
                     os.remove(outfile)
-                except:
+                except Exception:
                     _logger.warning("cannot delete file %s", outfile)
                 useExistingResult = 0
         else:
@@ -1514,7 +1521,7 @@ class McaBatchWindow(qt.QWidget):
                 #code removed, concentrations in McaAdvancedFitBatch.py
                 try:
                     os.remove(self._concentrationsFile)
-                except:
+                except Exception:
                     pass
                 """
                 pass
@@ -1610,7 +1617,7 @@ class McaBatchWindow(qt.QWidget):
             try:
                 dirname = os.path.dirname(__file__)
                 frozen = False
-            except:
+            except Exception:
                 frozen = True
                 dirname = os.path.dirname(EdfFileSimpleViewer.__file__)
             if not frozen:
@@ -1775,7 +1782,7 @@ def main():
                       concentrations=concentrations, fitfiles=fitfiles,
                       filebeginoffset=filebeginoffset,fileendoffset=fileendoffset,
                       mcaoffset=mcaoffset, chunk=chunk, selection=selection)
-        except:
+        except Exception:
             if exitonend:
                 _logger.warning("Error: ", sys.exc_info()[1])
                 _logger.warning("Quitting as requested")
@@ -1791,7 +1798,8 @@ def main():
         def cleanup():
             b.pleasePause = 0
             b.pleaseBreak = 1
-            b.wait()
+            if hasattr(b, "wait"):
+                b.wait()
             qApp = qt.QApplication.instance()
             qApp.processEvents()
 
