@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -153,7 +153,7 @@ class QDispatcher(qt.QWidget):
                                 try:
                                     dataObject = source.getDataObject(sel['Key'],
                                                           selection=sel['selection'])
-                                except:
+                                except Exception:
                                     if _logger.getEffectiveLevel() == logging.DEBUG:
                                         raise
                                     error = sys.exc_info()
