@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2021 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF.
@@ -24,7 +24,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -34,7 +34,7 @@ import numpy
 import logging
 
 from PyMca5.PyMcaGui import PyMcaQt as qt
-from PyMca5.PyMcaGui import PyMca_Icons
+from PyMca5.PyMcaGui.plotting import PyMca_Icons
 IconDict = PyMca_Icons.IconDict
 
 from matplotlib import __version__ as matplotlib_version
@@ -322,13 +322,16 @@ class QPyMcaMatplotlibSaveDialog(qt.QDialog):
         self.dismissButton.clicked.connect(self.reject)
 
     def exec_(self):
+        return self.exec()
+
+    def exec(self):
         self.plot.draw()
         if self.doNotShowAgain.isChecked():
             return qt.QDialog.Accepted
         else:
             if self._lastGoodSize is not None:
                 self.resize(self._lastGoodSize)
-            return qt.QDialog.exec_(self)
+            return qt.QDialog.exec(self)
 
     def accept(self):
         self._lastGoodSize = self.size()
