@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2020 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -63,7 +63,7 @@ class QSpsDataSource(QSource.QSource):
             if not hasattr(self, attr):
                 try:
                     return getattr(self.__dataSource, attr)
-                except:
+                except Exception:
                     pass
         raise AttributeError
 
@@ -130,7 +130,7 @@ if __name__ == "__main__":
     try:
         specname=sys.argv[1]
         arrayname=sys.argv[2]
-    except:
+    except Exception:
         print("Usage: SpsDataSource <specversion> <arrayname>")
         sys.exit()
     app=qt.QApplication([])
