@@ -2,10 +2,10 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2004-2014 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -244,7 +244,7 @@ def isThermoEMSFile(filename):
     f = open(filename, 'r')
     try:
         line = f.readline()
-    except:
+    except Exception:
         f.close()
         return False
     f.close()
@@ -253,7 +253,7 @@ def isThermoEMSFile(filename):
             if line.startswith("#FORMAT") or \
                (("EMSA" in line) and ("Spectral" in line)):
                 return True
-    except:
+    except Exception:
         pass
     return False
 
