@@ -24,23 +24,6 @@
 #define PyMca_LOCALE_MANAGEMENT_H
 
 #include <locale.h>
-#ifdef _GNU_SOURCE
-#  ifdef __GLIBC__
-#    include <features.h>
-#    if !((__GLIBC__ > 2) || ((__GLIBC__ == 2) && (__GLIBC_MINOR__ > 25)))
-#      /* strtod_l has been moved to stdlib.h since glibc 2.26 */
-#      include <xlocale.h>
-#    endif
-#  else
-#    include <xlocale.h>
-#  endif
-#else
-#  ifdef SPECFILE_POSIX
-#    ifndef LOCALE_NAME_MAX_LENGTH
-#           define LOCALE_NAME_MAX_LENGTH 85
-#    endif
-#  endif
-#endif
 
 double PyMcaAtof(const char*);
 
